package com.ruoyi.web.work.controller;

import java.util.Arrays;
import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.web.work.domain.HospitalDept;
import com.ruoyi.web.work.service.IHospitalDeptService;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 医院科室
 * @author lsw
 * @date 2024-07-09
 */
@RestController
@RequestMapping("/work/dept")
public class HospitalDeptController extends BaseController {
    @Autowired
    private IHospitalDeptService hospitalDeptService;

    @PreAuthorize("@ss.hasPermi('work:dept:list')")
    @GetMapping("/list")
    public TableDataInfo list(HospitalDept hospitalDept){
        startPage();
        List<HospitalDept> list = hospitalDeptService.selectList(hospitalDept);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasPermi('work:dept:query')")
    @GetMapping(value = "/detail/{id}")
    public AjaxResult detail(@PathVariable("id") Long id){
        return AjaxResult.success(hospitalDeptService.getById(id));
    }

    @PreAuthorize("@ss.hasPermi('work:dept:add')")
    @Log(title = "医院科室", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    public AjaxResult add(@RequestBody HospitalDept hospitalDept){
        return toAjax(hospitalDeptService.save(hospitalDept));
    }

    @PreAuthorize("@ss.hasPermi('work:dept:edit')")
    @Log(title = "医院科室", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody HospitalDept hospitalDept){
        return toAjax(hospitalDeptService.updateById(hospitalDept));
    }

    @PreAuthorize("@ss.hasPermi('work:dept:remove')")
    @Log(title = "医院科室", businessType = BusinessType.DELETE)
    @GetMapping("/remove/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids){
        return toAjax(hospitalDeptService.removeByIds(Arrays.asList(ids)));
    }
}
